/**
 * @file bit.h
 * @brief Contains the %Bit data type.
 */

#ifndef BIT_H
#define BIT_H

/**
 * @brief Enumeration to provide meaningful names for bit states.
 *
 * The binary values are chosen to match the logical states as well,
 * e.g. `if (x)` equals to `if (x == ONE)` and `if (x != ZERO)`.
 * However, this type should be used in situations only where there
 * are actual bits to refer to (e.g. the result from bit detection).
 * In situations where the logical character is dominant, `bool`
 * should be used instead.
 */
enum Bit
{
	ZERO = 0, ///< Binary zero
	ONE  = 1, ///< Binary one
};

#endif
