/**
 * @file logger.cpp
 * @brief Contains the %Logger class implementation.
 */

#include "logger.h"

// Putting this into PROGMEM and then creating special
// methods for access is probably not worth the effort.
static const char *captions[] =
{
	"[error]",
	"[warn]",
	"[info]",
	"[debug]",
};

Logger::Logger(Usart *usart, Level level) : m_usart(usart), m_level(level)
{
	m_usart.enable(true);
}

Logger::~Logger(void)
{
	m_usart.enable(false);
}

void Logger::write(Level level, const char *s)
{
	if (level <= m_level && s != nullptr)
	{
		write(captions[level]);
		m_usart.write(' ');
		write(s);
		m_usart.write('\r');
		m_usart.write('\n');
	}
}

void Logger::setLevel(Level level)
{
	m_level = level;
}

void Logger::write(const char *s)
{
	while (*s != '\0')
	{
		m_usart.write(*s++);
	}
}
